@@ -83,6 +83,10 @@ class Part(inventree.base.InventreeObject):
         """ Return parameters associated with this part """
         return inventree.base.Parameter.list(self._api, part=self.pk)
 
+    def getRelated(self):
+        """ Return related parts associated with this part """
+        return PartRelated.list(self._api, part=self.pk)
+
     def uploadImage(self, image):
         """
         Upload an image against this Part
@@ -111,6 +115,20 @@ class Part(inventree.base.InventreeObject):
 
         return response
 
+    def getInternalPriceList(self):
+        """
+        Returns the InternalPrice list for this part
+        """
+
+        return InternalPrice.list(self._api, part=self.pk)
+    
+    def setInternalPrice(self, quantity: int, price: float):
+        """
+        Set the internal price for this part
+        """
+
+        return InternalPrice.setInternalPrice(self._api, self.pk, quantity, price)
+
     def downloadImage(self, destination):
         """
         Download the image for this Part, to the specified destination
@@ -199,3 +217,46 @@ class BomItem(inventree.base.InventreeObject):
     """ Class representing the BomItem database model """
 
     URL = 'bom'
+
+
+class InternalPrice(inventree.base.InventreeObject):
+    """ Class representing the InternalPrice model """
+
+    URL = 'part/internal-price'
+
+    @classmethod
+    def setInternalPrice(cls, api, part, quantity: int, price: float):
+        """
+        Set the internal price for this part
+        """
+
+        data = {
+            'part': part,
+            'quantity': quantity,
+            'price': price,
+        }
+
+        # Send the data to the server
+        return api.post(cls.URL, data)
+    
+    
+class PartRelated(inventree.base.InventreeObject):
+    """ Class representing a relationship between parts"""
+
+    URL = 'part/related'
+
+    @classmethod
+    def add_related(cls, api, part1, part2):
+    
+        data = {
+            'part_1': part1,
+            'part_2': part2,
+        }
+        # Send the data to the server
+        if api.post(cls.URL, data):
+            logging.info("Related OK")
+            ret = True
+        else:
+            logging.warning("Related failed")
+            ret = False
+        return ret
